-- The following lines will hide the default blizzard buffs
BuffFrame:Hide()
TemporaryEnchantFrame:Hide()

-- Textures used feel free to swap them out with whatever you like!
-- ItsCool and OhCrap are the two textures used to indicate percentage health

local healthIndicator = 'Interface\\Addons\\oUF_Darnation\\media\\ItsCool'
local healthIndicatorSpark = 'Interface\\Addons\\oUF_Darnation\\media\\OhCrap'

-- Other Textures used in this unit frame

local textureInner = 'Interface\\Addons\\oUF_Darnation\\media\\circle'
local texturering = 'Interface\\Addons\\oUF_Darnation\\media\\ring'
local textureglow = 'Interface\\Addons\\oUF_Darnation\\media\\glow'
local castBar = 'Interface\\Addons\\oUF_Darnation\\media\\rothTex'
local font = 'Interface\\AddOns\\oUF_Darnation\\media\\Russel Square LT.ttf'

-- largeSize is the size of the Player, Target and Focus unit frames
-- smallSize is the size of all of the other unit frames (including party)

local largeSize = 80
local smallSize = largeSize*.65
local groupSize = largeSize*.45

-- Alpha and color  of the center health indicator. Currently set to be mostly transparent and white
local healthAlpha = .15
oUF.colors.health = {1,1,1}

-- Percentage of health to kick in different behaviors
local fleshWound = .80
local ouch = .60
local uhOh = .40
local imToast = .20

-- Buff/Debuff Max size on target
local maxDebuff = 32
local maxBuff = 32

-- Turn Castbars on/off
local castBarsToggle = true

local r2, r42, realUpdate, colorTable = math.sqrt(0.5^2+0.5^2), math.sqrt(42), true, {[4]=0.9};

local function menu(self)
	local unit = self.unit:sub(1, -2)
	local cunit = self.unit:gsub('(.)', string.upper, 1)

	if(unit == 'party' or unit == 'partypet') then
		ToggleDropDownMenu(1, nil, _G['PartyMemberFrame'..self.id..'DropDown'], 'cursor', 0, 0)
	elseif(_G[cunit..'FrameDropDown']) then
		ToggleDropDownMenu(1, nil, _G[cunit..'FrameDropDown'], 'cursor', 0, 0)
	end
end

local classification = {
	worldboss = '|cffD7BEA5Boss|r',
	rareelite = '|cffD7BEA5%s+ Rare|r',
	elite = '|cffD7BEA5%s+|r',
	rare = '|cffD7BEA5%s Rare|r',
	normal = '|cffD7BEA5%s|r',
	trivial = '|cffD7BEA5%s|r',
}

local function updateColor(self, element, unit, func)
	local color
        local colorAlpha = 1 

	if(UnitIsDead(unit) or UnitIsGhost(unit) or not UnitIsConnected(unit) or (UnitIsTapped(unit) and not UnitIsTappedByPlayer(unit))) then
	   return element[func](element, .84,.75,.65)
	elseif(unit == 'pet') then
	   color = self.colors.happiness[GetPetHappiness()] or self.colors.power[UnitPowerType(unit)]
	elseif(UnitIsPlayer(unit)) then
	   local _, class = UnitClass(unit)
	   color = self.colors.class[class]
	else
	   color = self.colors.reaction[UnitReaction(unit, 'player')] or self.colors.health
	end

	if(color) then
	   element[func](element, color[1], color[2], color[3], colorAlpha)
	end
end

local function SetFontString(parent, fontName, fontHeight, fontStyle)
	local fs = parent:CreateFontString(nil, 'OVERLAY')
	fs:SetFont(fontName, fontHeight, fontStyle)
	fs:SetJustifyH('LEFT')
	fs:SetShadowColor(0,0,0)
	fs:SetShadowOffset(1.25, -1.25)
	return fs
end

local numberize = function(value)
	if value <= 99999 then
		return value
	elseif value <= 999999 then
		return string.format('%.1fk', value / 1000)
	else
		return string.format('%.2fm', value / 1000000)
	end
end

local function updateName(self, event, unit)
	if(self.unit == unit) then
		updateColor(self, self.Name, unit, 'SetTextColor')

		local uName = UnitName(unit)
                -- Get the class name, though getting the icon should go on the to do list..
                local cName = UnitClass(unit)

		if(unit == 'target' or unit == 'player') then
			local level = (not UnitIsConnected(unit)) and '??' or UnitLevel(unit) < 0 and '??' or UnitLevel(unit)
                        -- Name length should not be an issue
                        -- However if the target does not have a class then we do not want the name repeated (I think this is only for NPC's and Pets)
                        -- It would be useful to know the type of creature targeted...
                        if(cName == uName) then
                           cName = UnitCreatureType(unit)
                        end 
                        if (cName) then
			   self.Name:SetFormattedText('%s |cff0090ff%s|r \n [%s]', uName, format(classification[UnitClassification(unit)], level), cName)
                        else
			   self.Name:SetFormattedText('%s |cff0090ff%s|r \n [Pet]', uName, format(classification[UnitClassification(unit)], level))
                        end
		elseif (unit == 'pet' and uName == 'Unknown') then
			self.Name:SetText('Pet')
		elseif (unit == 'targettarget' or unit == 'focus' or unit == 'pet') then
			self.Name:SetText(uName)
                else
			if string.len(uName) > 5 then
				self.Name:SetFormattedText('%s...', uName:sub(1, 5))
			else
				self.Name:SetText(uName)
			end
		end
	end
end

local function updateHealth(self, event, unit, bar, min, max)

	local LibMobHealth
	if LibStub then LibMobHealth = LibStub('LibMobHealth-4.0', true) end
	local cur, maxhp
	if LibMobHealth then
		cur, maxhp = LibMobHealth:GetUnitHealth(unit)
	else
		cur, maxhp = min, max
	end

	local percText = string.format('%d%%', min/max*100)

        local perc = cur/maxhp

	if(UnitIsDead(unit)) then
		bar.value:SetText('Dead')
	elseif(UnitIsGhost(unit)) then
		bar:SetValue(max)
		bar.value:SetText('Ghost')
	elseif(not UnitIsConnected(unit)) then
		bar.value:SetText('Offline')
	else
		if(cur~=maxhp) then
		   bar.value:SetText('|cffAF5050'..percText..'|r ')
		else
		   bar.value:SetText('|cffAF5050'..numberize(max))
		end
                self.HealthRing:SetTexture(nil)
                self.HealthRing:SetTexture(healthIndicator)
                if(perc < imToast) then 
                   self.HealthRing:SetTexture(nil)
                   self.HealthRing:SetTexture(healthIndicatorSpark)
	           self.HealthRing:SetVertexColor(1,0,0,.7)
                elseif (perc < uhOh) then
                   self.HealthRing:SetTexture(nil)
                   self.HealthRing:SetTexture(healthIndicatorSpark)
	           self.HealthRing:SetVertexColor(1,1,0,.7)
                elseif (perc < ouch) then
                   self.HealthRing:SetTexture(nil)
                   self.HealthRing:SetTexture(healthIndicator)
	           self.HealthRing:SetVertexColor(1,1,0,.7)
                elseif (perc < fleshWound) then
                   self.HealthRing:SetTexture(nil)
                   self.HealthRing:SetTexture(healthIndicator)
	           self.HealthRing:SetVertexColor(0,1,0,.7)
                else
                   self.HealthRing:SetTexture(nil)
                end
                if(min <= 1) then
	           self.HealthRing:SetVertexColor(0,0,0,.7)
                end
                if(not self:GetScript("OnUpdate")) then
                   self:SetScript("OnUpdate", function(self, elapsed)
                   local time = GetTime()
                   local ofs = time*135
	           local health =  self.HealthRing 
                   health:SetTexCoord(
	                	0.5+r2*cos(ofs+135), 0.5+r2*sin(ofs+135),
	                 	0.5+r2*cos(ofs-135), 0.5+r2*sin(ofs-135),
	                 	0.5+r2*cos(ofs+45), 0.5+r2*sin(ofs+45),
	                 	0.5+r2*cos(ofs-45), 0.5+r2*sin(ofs-45)
	                  )
                end)
                end
	end
	if(UnitIsDead(unit) or UnitIsGhost(unit) or not UnitIsConnected(unit) or (UnitIsTapped(unit) and not UnitIsTappedByPlayer(unit))) then
		bar:SetStatusBarColor(.31*.25, .45*.25, .63*.25)
	        self.HealthRing:SetVertexColor(0,0,0,1)
	else
		local r, g, b = oUF.ColorGradient(min/max, 1,1,1, .90,.90,.90, .85,.85,.85)
		bar:SetStatusBarColor(r, g, b, healthAlpha)
	end
        
	self:UNIT_NAME_UPDATE(event, unit)
end

local function updatePower(self, event, unit, bar, min, max)

	if(self.unit == unit) then
	   updateColor(self, bar.value, unit, 'SetTextColor')

	   if(UnitIsDead(unit) or UnitIsGhost(unit)) then
		bar:SetValue(0)
	   elseif(not UnitIsConnected(unit)) then
		bar.value:SetText()
	   elseif( max == 0) then
		bar.value:SetText()
	   else
	        bar.value:SetText(numberize(min))
	   end
	   self:UNIT_NAME_UPDATE(event, unit)
	end

end

local function auraIcon(self, button, icons, index, debuff)
	icons.showDebuffType = true
	button.cd:SetReverse()
	button.icon:SetTexCoord(.07, .93, .07, .93)
	button.count:SetPoint('BOTTOMRIGHT', button, 1, 0)
	button.count:SetTextColor(.84,.75,.65)
	button:SetScript('OnMouseUp', function(self, mouseButton)
		if mouseButton == 'RightButton' then
			local name, rank = UnitBuff('player', index)
			CancelPlayerBuff(name, rank)
		end
	end)

	self.ButtonOverlay = button:CreateTexture(nil, 'OVERLAY')
	self.ButtonOverlay:SetTexture('Interface\\AddOns\\oUF_Darnation\\media\\entropy\\border')
	self.ButtonOverlay:SetParent(button)
	self.ButtonOverlay:SetPoint('TOPLEFT', -3, 3)
	self.ButtonOverlay:SetPoint('BOTTOMRIGHT', 3, -3)
	self.ButtonOverlay:SetVertexColor(.31,.45,.63,1)
	self.ButtonOverlay:SetBlendMode('BLEND')

end

local function styleFunc(self, unit)
	local _, class = UnitClass('player')
	self.menu = menu
	self:RegisterForClicks('AnyUp')
	self:SetAttribute('*type2', 'menu')
	self:SetScript('OnEnter', UnitFrame_OnEnter)
	self:SetScript('OnLeave', UnitFrame_OnLeave)

	self:SetBackdrop({bgFile = textureInner, insets = {top = -30, left = -30, bottom = -30, right = -30}})
	self:SetBackdropColor(1,1,1,0)

	self.Health = CreateFrame('StatusBar', nil, self)
	self.Highlight = self:CreateTexture(nil, 'HIGHLIGHT')
	self.InnerRing = self:CreateTexture(nil, 'LOW')
	self.HealthRing = self:CreateTexture(nil, 'MEDIUM')
	self.DebuffHighlight = self:CreateTexture(nil, 'HIGH')
	self.Power = CreateFrame('StatusBar', nil, self)
     
        local size 
        if unit == 'player' or unit == 'target' then
                size = largeSize
        elseif unit == 'focus' or unit == 'targettarget' or unit == 'pet' then
                size = smallSize
        else
                size = groupSize
        end

        self.Health:SetHeight(size*.95)
        self.Health:SetWidth(size*.95)
        self.Highlight:SetHeight(size*1.80)
        self.Highlight:SetWidth(size*1.80)
        self.InnerRing:SetWidth(size*1.4)
        self.InnerRing:SetHeight(size*1.4)
        self.DebuffHighlight:SetWidth(size*.20)
        self.DebuffHighlight:SetHeight(size*.20)
        self.HealthRing:SetWidth(size*1.60)
        self.HealthRing:SetHeight(size*1.60)

	self.Health:SetFrameLevel(1) -- puts the hp frame lower than the highlight frame
	self.Health:SetPoint('CENTER')
        self.Health:SetStatusBarTexture(textureInner)
	self.Health.bg = self.Health:CreateTexture(nil, 'BORDER')
	self.Health.bg:SetTexture(textureInner)
	self.Health.bg:SetAllPoints(self.Health)
	self.Health.bg:SetVertexColor(.15,.15,.15,.1)

        if (unit == 'target' or unit == 'player') then
	   self.Health.value = SetFontString(self.Health, font, 22)
	   self.Health.value:SetPoint('CENTER', self.Health,'CENTER',0, 5)
	   self.Power.value = SetFontString(self.Health, font, 18)
	   self.Power.value:SetPoint('CENTER', self.Health, 'CENTER', 0, -size*.3)
        elseif (unit == 'focus') then
	   self.Health.value = SetFontString(self.Health, font, 16)
	   self.Health.value:SetPoint('CENTER', self.Health,'CENTER',0, 5)
	   self.Power.value = SetFontString(self.Health, font, 14)
	   self.Power.value:SetPoint('CENTER', self.Health, 'CENTER', 0, -size*.3)
        else
	   self.Health.value = SetFontString(self.Health, font, 16)
	   self.Health.value:SetPoint('CENTER', self.Health,'CENTER',0, 5)
	   self.Power.value = SetFontString(self.Health, font, 12)
	   self.Power.value:SetPoint('CENTER', self.Health, 'CENTER', 0, -size*.3)
        end
	self.InnerRing:SetPoint('CENTER', self.Health,'CENTER',0, 0)
	self.InnerRing:SetTexture(texturering)
	self.InnerRing:SetBlendMode('ADD')
	self.InnerRing:SetVertexColor(1,1,1,.1)

	self.HealthRing:SetPoint('CENTER', self.Health,'CENTER',0, 0)
	self.HealthRing:SetTexture(healthIndicator)
	self.HealthRing:SetBlendMode('ADD')
	self.HealthRing:SetVertexColor(1,1,1,0)

	self.Highlight:SetPoint('CENTER', self.Health,'CENTER',0, 0)
	self.Highlight:SetTexture(textureglow)
	self.Highlight:SetBlendMode('ADD')

	self.Power:SetFrameLevel(1) -- puts the hp frame lower than the highlight frame
	self.Power:SetPoint('CENTER', self.Health, 'CENTER', 0, 0)


	if(unit=='target' or unit == 'player') then
		self.Name = SetFontString(self.Health, font, 18)
	        self.Name:SetPoint('TOPLEFT', 1, 53)
        elseif (unit=='party') then
	        self.Name = SetFontString(self.Health, font, 14)
	        self.Name:SetPoint('TOPLEFT', 1, 40)
        else
	        self.Name = SetFontString(self.Health, font, 14)
	        self.Name:SetPoint('TOPLEFT', 1, 23)
	end

	if(not unit or unit=='player') then
		self.Leader = self.Health:CreateTexture(nil, 'OVERLAY')
		self.Leader:SetHeight(16)
		self.Leader:SetWidth(16)
		self.Leader:SetPoint('TOPLEFT', self.Health, -10, 8)
		self.Leader:SetTexture('Interface\\GroupFrame\\UI-Group-LeaderIcon')
	end

	self.RaidIcon = self.Health:CreateTexture(nil, 'OVERLAY')
	self.RaidIcon:SetHeight(16)
	self.RaidIcon:SetWidth(16)
	self.RaidIcon:SetPoint('TOPRIGHT', self.Health, 16, 8)
	self.RaidIcon:SetTexture('Interface\\TargetingFrame\\UI-RaidTargetingIcons')

	self.CombatIcon = self.Health:CreateTexture(nil, 'OVERLAY')
	self.CombatIcon:SetPoint('TOPLEFT', self.Health, 'TOPRIGHT', -10, 15)
	self.CombatIcon:SetHeight((unit and not unit:find('partypet%d')) and 14 or 10)
	self.CombatIcon:SetWidth((unit and not unit:find('partypet%d')) and 14 or 10)
	self.CombatIcon:SetTexture('Interface\\CharacterFrame\\UI-StateIcon')
	self.CombatIcon:SetTexCoord(0.58, 0.90, 0.08, 0.41)
	self.Combat = self.CombatIcon

	local punit = 'not'
        if (self.unit) then
           punit = self.unit:sub(1, -2)
        end

        self.sortAuras = {} -- This will allow this frame to have its auras sorted
       -- self.sortAuras.reverse = true -- Option to reverse the sorting.
        self.sortAuras.selfFirst = true

	if(unit == 'pet') then
		self.Buffs = CreateFrame('Frame', nil, self)
		self.Buffs.spacing = 5.3
		self.Buffs:SetHeight(25)
		self.Buffs:SetWidth(75)
		self.Buffs:SetPoint('TOPRIGHT', self, 'TOPLEFT', -4, -1.5)
		self.Buffs['growth-x'] = 'LEFT'
		self.Buffs['growth-y'] = 'DOWN'
		self.Buffs.initialAnchor = 'TOPRIGHT'
		self.Buffs.size = math.floor(self.Buffs:GetHeight())
	end

	if(unit == 'target') then
		self.Buffs = CreateFrame('Frame', nil, self)
		self.Buffs.num = maxBuff 
		self.Buffs.spacing = 5.3
		self.Buffs:SetHeight(25)
		self.Buffs:SetWidth(250)
		self.Buffs:SetPoint('TOPLEFT', self, 'TOPRIGHT', -4, -25)
		self.Buffs.initialAnchor = 'TOPLEFT'
		self.Buffs['growth-y'] = 'DOWN'
		self.Buffs.size = math.floor(self.Buffs:GetHeight())
        end

	if(unit == 'target') then
		self.Debuffs = CreateFrame('Frame', nil, self)
		self.Debuffs.num = maxDebuff 
		self.Debuffs.spacing = 5.3
		self.Debuffs:SetHeight(25)
		self.Debuffs:SetWidth(230)
		self.Debuffs:SetPoint('TOPLEFT', self, 'BOTTOMLEFT', -10, -30)
		self.Debuffs.initialAnchor = 'TOPLEFT'
		self.Debuffs['growth-y'] = 'DOWN'
		self.Debuffs.showDebuffType = true
		self.Debuffs.size = math.floor(self.Debuffs:GetHeight())

		if(class == 'ROGUE' or class == 'DRUID') then
			self.CPoints = SetFontString(self.Health, font, 24, 'OUTLINE')
			self.CPoints:SetPoint('RIGHT', self, 'LEFT', -9, 3)
			self.CPoints:SetTextColor(.84, .75, .65)
			self.CPoints:SetJustifyH('RIGHT')
		end
	end

	if(castBarsToggle and (unit == 'player' or unit == 'focus' or unit == 'target')) then
		self.Castbar = CreateFrame('StatusBar', nil, self)
		self.Castbar:SetBackdrop({bgFile = texturering, insets = {top = -4, left = -4, bottom = -4, right = -4}})
		self.Castbar:SetBackdropColor(.25,.25,.25,1)
		self.Castbar:SetStatusBarTexture(texturering)
		self.Castbar:SetWidth(size*1.5)
		self.Castbar:SetHeight(size*.85)
		self.Castbar:SetParent(self)
                if (unit == 'focus') then
		   self.Castbar:SetStatusBarColor(1,0,0,.9)
		   self.Castbar:SetPoint('LEFT', self.Health,'CENTER',80,0)
                elseif (unit == 'player') then
		   self.Castbar:SetStatusBarColor(.5,1,0,.9)
		   self.Castbar:SetPoint('LEFT', self.Health,'CENTER',80,0)
                else
		   self.Castbar:SetStatusBarColor(1,.5,0,.9)
		   self.Castbar:SetPoint('RIGHT', self.Health,'CENTER',-80,0)
                end
		self.Castbar:SetMinMaxValues(1, 100)
		self.Castbar:SetValue(1)
		self.Castbar:Hide()
		Castbar = self.Castbar

		self.Castbar.bg = self.Castbar:CreateTexture(nil, 'BORDER')
		self.Castbar.bg:SetAllPoints(self.Castbar)
		self.Castbar.bg:SetTexture(texturering)
		self.Castbar.bg:SetVertexColor(.15,.15,.15,.9)
		self.Castbar.bg = self.Castbar.bg
		Castbar.bg = self.Castbar.bg

		self.Castbar.Safezone = self.Castbar:CreateTexture(nil,'ARTWORK')
		self.Castbar.Safezone:SetTexture(castBar)
		self.Castbar.Safezone:SetVertexColor(.31,.45,.63,1)
		self.Castbar.Safezone:SetPoint('TOPRIGHT')
		self.Castbar.Safezone:SetPoint('BOTTOMRIGHT')
		Castbar.safezone = self.Castbar.Safezone

		self.Castbar.Text = SetFontString(self.Castbar, font, 16)
		self.Castbar.Text:SetPoint('CENTER', self.Castbar,'CENTER', 73, 0)
		self.Castbar.Text:SetWidth(230)
		self.Castbar.Text:SetTextColor(1,1,1)
		Castbar.text = self.Castbar.Text

		self.Castbar.Time = SetFontString(self.Castbar, font, 12)
		self.Castbar.Time:SetPoint('RIGHT', self.Castbar, -1, 20)
		self.Castbar.Time:SetTextColor(.84,.75,.65)
		self.Castbar.Time:SetJustifyH('CENTER',-5,0)
		Castbar.casttime = self.Castbar.Time

		end

	self.DebuffHighlight:SetPoint('CENTER', self.Health,'CENTER',0, size*.3)
	self.DebuffHighlight:SetTexture(textureInner)
	self.DebuffHighlight:SetBlendMode('ADD')
	self.DebuffHighlight:SetVertexColor(.84,.75,.65,0) -- set alpha to 0 to hide the texture
	self.DebuffHighlightAlpha = 1
	self.DebuffHighlightBackdrop = false
	self.DebuffHighlightFilter = false

	function self.Banzai(self, unit, aggro)
		if aggro == 1 then
	                self.InnerRing:SetVertexColor(1,0,0,.4)
		else
	                self.InnerRing:SetVertexColor(1,1,1,.1)
		end
	end

	if(unit == 'player' or unit == 'target') then
		self.CombatFeedbackText = SetFontString(self.Health, font, 18, 'OUTLINE')
		self.CombatFeedbackText:SetPoint('CENTER', self.Health, 'CENTER', 0, 25)
		self:SetAttribute('initial-height', 120)
		self:SetAttribute('initial-width', 120)
	else
		self:SetAttribute('initial-height', 60)
		self:SetAttribute('initial-width', 60)
	end

	if(not unit) then
		self.outsideRangeAlpha = 0.5
		self.inRangeAlpha = 1.0
		self.Range = true
	end

	self.PostUpdateHealth = updateHealth
	self.PostUpdatePower = updatePower
	self.PostCreateAuraIcon = auraIcon
	self.UNIT_NAME_UPDATE = updateName
	self.UNIT_HAPPINESS = updateName
	self.PLAYER_TARGET_CHANGED = updateTarget

	return self
end


oUF:RegisterStyle('Darnation', styleFunc)

oUF:SetActiveStyle('Darnation')

oUF:Spawn('player'):SetPoint('CENTER', UIParent, -250, -180)
oUF:Spawn('target'):SetPoint('CENTER', UIParent, 250, -180)
oUF:Spawn('pet'):SetPoint('BOTTOMLEFT', oUF.units.player, 'BOTTOMLEFT',-(largeSize*.70), 7)
oUF:Spawn('focus'):SetPoint('BOTTOMLEFT', oUF.units.player, 'TOPRIGHT', 0, largeSize*.40)
oUF:Spawn('targettarget'):SetPoint('BOTTOMRIGHT', oUF.units.target, 'TOPLEFT', 0, largeSize*.40)

local party = oUF:Spawn('header', 'oUF_Party')
party:SetPoint('TOPLEFT', UIParent, 'TOPLEFT', 15, -20)
party:SetManyAttributes('yOffset', -20, 'showParty', true)

local partyToggle = CreateFrame('Frame')
local partytarget = {}
for i = 1, 5 do
	partytarget[i] = oUF:Spawn('party'..i..'target', 'oUF_Party'..i..'Target')
	if i == 1 then
		partytarget[i]:SetPoint('TOPLEFT', party, 'TOPRIGHT', 10, 0)
	else
		partytarget[i]:SetPoint('TOP', partytarget[i-1], 'BOTTOM', 0, -20)
	end
end

local raid = {}
for i = 1, 8 do
	local raidgroup = oUF:Spawn('header', 'oUF_Raid'..i)
	raidgroup:SetManyAttributes('groupFilter', tostring(i), 'showRaid', true, 'yOffSet', -5)
	table.insert(raid, raidgroup)
	if(i==1) then
		raidgroup:SetPoint('TOPLEFT', UIParent, 'TOPLEFT', 15, -15)
	else
		raidgroup:SetPoint('TOPLEFT', raid[i-1], 'TOPRIGHT', 5, 0)
	end
end

partyToggle:RegisterEvent('PLAYER_LOGIN')
partyToggle:RegisterEvent('RAID_ROSTER_UPDATE')
partyToggle:RegisterEvent('PARTY_LEADER_CHANGED')
partyToggle:RegisterEvent('PARTY_MEMBER_CHANGED')
partyToggle:SetScript('OnEvent', function(self)
	if(InCombatLockdown()) then
		self:RegisterEvent('PLAYER_REGEN_ENABLED')
	else
		self:UnregisterEvent('PLAYER_REGEN_ENABLED')
		if(GetNumRaidMembers() > 5) then
			party:Hide()
			for i,v in ipairs(raid) do v:Show() end
			for i,v in ipairs(partytarget) do v:Disable()	end
		else
			party:Show()
			for i,v in ipairs(raid) do v:Hide() end
			for i,v in ipairs(partytarget) do v:Enable() end
		end

	end
end)
